@@ -7,12 +7,12 @@ __lock = ReadWriteLock()
 
 
 def initialize(project_secret,
-               time_to_leave_seconds=60,
+               time_to_live_seconds=60,
                config_store_class=None):
     """
     Initializes the BetterConfigClient. If the client is already initialized it does nothing
     :param project_secret: The Project's Project secret
-    :param time_to_leave_seconds: TTL for the cache
+    :param time_to_live_seconds: TTL for the cache
     :param config_store_class: Customizable ConfigStore caching provider
     """
     global __client
@@ -27,14 +27,15 @@ def initialize(project_secret,
         if __client:
             return
 
-        __client = BetterConfigClient(project_secret, time_to_leave_seconds, config_store_class)
+        __client = BetterConfigClient(project_secret, time_to_live_seconds, config_store_class)
     finally:
         __lock.release_write()
 
 
 def get():
     """
-    Gets the initialized BetterConfigClient. In case you haven't called initialize before it raises a BetterConfigClientException.
+    Gets the initialized BetterConfigClient.
+    In case you haven't called initialize before it raises a BetterConfigClientException.
     :return: The initialized BetterConfigClient.
     """
     global __client
@@ -47,10 +48,22 @@ def get():
     finally:
         __lock.release_read()
 
+    raise BetterConfigClientException("Initialize should be called before using BetterConfigClient")
+
+
+def close():
+    """
+    Closes all resources
+    """
+    global __client
+    global __lock
+
     try:
         __lock.acquire_write()
-        if not __client:
-            raise BetterConfigClientException("Initialize should be called before using BetterConfigClient")
-        return __client
+
+        if __client:
+            __client.close()
+
+        __client = None
     finally:
-        __lock.unlock()
+        __lock.release_write()
