@@ -9,19 +9,20 @@ class BetterConfigClient(object):
 
     def __init__(self,
                  project_secret,
-                 time_to_leave_seconds=60,
+                 time_to_live_seconds=60,
                  config_store_class=None):
         """
         Initializes the BetterConfigClient
         :param project_secret: The Project's Project secret
-        :param time_to_leave_seconds: TTL for the cache
+        :param time_to_live_seconds: TTL for the cache
         :param config_store_class: Customizable ConfigStore caching provider
         """
+        self._project_secret = project_secret
         self._config_fetcher = CacheControlConfigFetcher(project_secret)
         if config_store_class:
             self._config_store = config_store_class(self._config_fetcher)
         else:
-            self._config_store = InMemoryConfigStore(self._config_fetcher, time_to_leave_seconds)
+            self._config_store = InMemoryConfigStore(self._config_fetcher, time_to_live_seconds)
 
     def get_configuration_json(self):
         """
