@@ -2,8 +2,8 @@ import requests
 import logging
 import sys
 from cachecontrol import CacheControl
-from betterconfigclient.interfaces import ConfigFetcher
-from betterconfigclient.version import BETTERCONFIGCLIENT_VERSION
+from .interfaces import ConfigFetcher
+from .version import BETTERCONFIGCLIENT_VERSION
 
 BASE_URI = 'https://cdn.betterconfig.com/configuration-files/'
 BASE_EXTENSION = '/config.json'
@@ -18,7 +18,7 @@ def _headers():
 class CacheControlConfigFetcher(ConfigFetcher):
 
     def __init__(self, project_secret):
-        super().__init__(project_secret)
+        super(CacheControlConfigFetcher, self).__init__(project_secret)
         self._project_secret = project_secret
         self._session = requests.Session()
         self._request_cache = CacheControl(self._session)
