@@ -10,13 +10,13 @@ log = logging.getLogger(sys.modules[__name__].__name__)
 
 class InMemoryConfigStore(ConfigStore):
 
-    def __init__(self, config_fetcher, time_to_leave_seconds):
+    def __init__(self, config_fetcher, time_to_live_seconds):
         super(InMemoryConfigStore, self).__init__(config_fetcher)
         self._lock = ReadWriteLock()
         self._config = None
         self._last_updated = None
         self._config_fetcher = config_fetcher
-        self._time_to_leave = datetime.timedelta(seconds=time_to_leave_seconds)
+        self._time_to_live = datetime.timedelta(seconds=time_to_live_seconds)
 
     def get(self):
         try:
@@ -25,7 +25,7 @@ class InMemoryConfigStore(ConfigStore):
             utc_now = datetime.datetime.utcnow()
             if self._config is not None \
                     and self._last_updated is not None \
-                    and self._last_updated + self._time_to_leave > utc_now:
+                    and self._last_updated + self._time_to_live > utc_now:
                 return self._config
         finally:
             self._lock.release_read()
@@ -36,7 +36,7 @@ class InMemoryConfigStore(ConfigStore):
             utc_now = datetime.datetime.utcnow()
             if self._config is not None \
                     and self._last_updated is not None \
-                    and self._last_updated + self._time_to_leave > utc_now:
+                    and self._last_updated + self._time_to_live > utc_now:
                 return self._config
 
             try:
